@@ -7,34 +7,17 @@
 
 /** @typedef {import("../Compiler")} Compiler */
 /** @typedef {import("./StatsPrinter")} StatsPrinter */
-
-/**
- * @typedef {Object} UsualContext
- * @property {string} type
- * @property {Object} compilation
- * @property {Object} asset
- * @property {Object} module
- * @property {Object} chunk
- * @property {Object} moduleReason
- * @property {(str: string) => string} bold
- * @property {(str: string) => string} yellow
- * @property {(str: string) => string} red
- * @property {(str: string) => string} green
- * @property {(str: string) => string} magenta
- * @property {(str: string) => string} cyan
- * @property {(file: string, oversize?: boolean) => string} formatFilename
- * @property {(id: string) => string} formatModuleId
- * @property {(id: string, direction?: "parent"|"child"|"sibling") => string} formatChunkId
- * @property {(size: number) => string} formatSize
- * @property {(flag: string) => string} formatFlag
- * @property {(time: number, boldQuantity?: boolean) => string} formatTime
- * @property {number} maxModuleId
- * @property {string} chunkGroupKind
- */
+/** @typedef {import("./StatsPrinter").StatsPrinterContext} StatsPrinterContext */
 
 const plural = (n, singular, plural) => (n === 1 ? singular : plural);
 
-const printSizes = (sizes, { formatSize }) => {
+/**
+ * @param {Record<string, number>} sizes sizes by source type
+ * @param {Object} options options
+ * @param {(number) => string=} options.formatSize size formatter
+ * @returns {string} text
+ */
+const printSizes = (sizes, { formatSize = n => `${n}` }) => {
 	const keys = Object.keys(sizes);
 	if (keys.length > 1) {
 		return keys.map(key => `${formatSize(sizes[key])} (${key})`).join(" ");
@@ -49,29 +32,104 @@ const mapLines = (str, fn) => str.split("\n").map(fn).join("\n");
  * @param {number} n a number
  * @returns {string} number as two digit string, leading 0
  */
-const twoDigit = n => (n > 10 ? `${n}` : `0${n}`);
+const twoDigit = n => (n >= 10 ? `${n}` : `0${n}`);
 
 const isValidId = id => {
 	return typeof id === "number" || id;
 };
 
-/** @type {Record<string, (thing: any, context: UsualContext, printer: StatsPrinter) => string | void>} */
+/** @type {Record<string, (thing: any, context: StatsPrinterContext, printer: StatsPrinter) => string | void>} */
 const SIMPLE_PRINTERS = {
-	"compilation.hash": (hash, { bold, type }) =>
-		type === "compilation.hash" ? `Hash: ${bold(hash)}` : undefined,
-	"compilation.version": (version, { bold, type }) =>
-		type === "compilation.version"
-			? `Version: webpack ${bold(version)}`
-			: undefined,
-	"compilation.time": (time, { formatTime }) =>
-		`Time: ${formatTime(time, true)}`,
-	"compilation.builtAt": (builtAt, { bold }) => {
-		const d = new Date(builtAt);
-		const x = twoDigit;
-		const date = `${d.getFullYear()}-${x(d.getMonth() + 1)}-${x(d.getDate())}`;
-		const time = `${x(d.getHours())}:${x(d.getMinutes())}:${x(d.getSeconds())}`;
-		return `Built at: ${date} ${bold(time)}`;
+	"compilation.summary!": (
+		_,
+		{
+			type,
+			bold,
+			green,
+			red,
+			yellow,
+			formatDateTime,
+			formatTime,
+			compilation: {
+				name,
+				hash,
+				version,
+				time,
+				builtAt,
+				errorsCount,
+				warningsCount
+			}
+		}
+	) => {
+		const root = type === "compilation.summary!";
+		const warningsMessage =
+			warningsCount > 0
+				? yellow(
+						`${warningsCount} ${plural(warningsCount, "warning", "warnings")}`
+				  )
+				: "";
+		const errorsMessage =
+			errorsCount > 0
+				? red(`${errorsCount} ${plural(errorsCount, "error", "errors")}`)
+				: "";
+		const timeMessage = root && time ? ` in ${formatTime(time)}` : "";
+		const hashMessage = hash ? ` (${hash})` : "";
+		const builtAtMessage =
+			root && builtAt ? `${formatDateTime(builtAt)}: ` : "";
+		const versionMessage = root && version ? `webpack ${version}` : "";
+		const nameMessage =
+			root && name
+				? bold(name)
+				: name
+				? `Child ${bold(name)}`
+				: root
+				? ""
+				: "Child";
+		const subjectMessage =
+			nameMessage && versionMessage
+				? `${nameMessage} (${versionMessage})`
+				: versionMessage || nameMessage || "webpack";
+		let statusMessage;
+		if (errorsMessage && warningsMessage) {
+			statusMessage = `compiled with ${errorsMessage} and ${warningsMessage}`;
+		} else if (errorsMessage) {
+			statusMessage = `compiled with ${errorsMessage}`;
+		} else if (warningsMessage) {
+			statusMessage = `compiled with ${warningsMessage}`;
+		} else if (errorsCount === 0 && warningsCount === 0) {
+			statusMessage = `compiled ${green("successfully")}`;
+		} else {
+			statusMessage = `compiled`;
+		}
+		if (
+			builtAtMessage ||
+			versionMessage ||
+			errorsMessage ||
+			warningsMessage ||
+			(errorsCount === 0 && warningsCount === 0) ||
+			timeMessage ||
+			hashMessage
+		)
+			return `${builtAtMessage}${subjectMessage} ${statusMessage}${timeMessage}${hashMessage}`;
 	},
+	"compilation.filteredWarningDetailsCount": count =>
+		count
+			? `${count} ${plural(
+					count,
+					"warning has",
+					"warnings have"
+			  )} detailed information that is not shown.\nUse 'stats.errorDetails: true' resp. '--stats-error-details' to show it.`
+			: undefined,
+	"compilation.filteredErrorDetailsCount": (count, { yellow }) =>
+		count
+			? yellow(
+					`${count} ${plural(
+						count,
+						"error has",
+						"errors have"
+					)} detailed information that is not shown.\nUse 'stats.errorDetails: true' resp. '--stats-error-details' to show it.`
+			  )
+			: undefined,
 	"compilation.env": (env, { bold }) =>
 		env
 			? `Environment (--env): ${bold(JSON.stringify(env, null, 2))}`
@@ -105,33 +163,13 @@ const SIMPLE_PRINTERS = {
 	},
 	"compilation.assetsByChunkName": () => "",
 
-	"compilation.modules": (modules, context) => {
-		let maxModuleId = 0;
-		for (const module of modules) {
-			if (typeof module.id === "number") {
-				if (maxModuleId < module.id) maxModuleId = module.id;
-			}
-		}
-		context.maxModuleId = maxModuleId;
-	},
-	"compilation.filteredModules": (
-		filteredModules,
-		{ compilation: { modules } }
-	) =>
+	"compilation.filteredModules": filteredModules =>
 		filteredModules > 0
-			? `   ${
-					modules && modules.length > 0
-						? ` + ${filteredModules} hidden`
-						: filteredModules
-			  } ${plural(filteredModules, "module", "modules")}`
+			? `${filteredModules} ${plural(filteredModules, "module", "modules")}`
 			: undefined,
 	"compilation.filteredAssets": (filteredAssets, { compilation: { assets } }) =>
 		filteredAssets > 0
-			? `${
-					assets && assets.length > 0
-						? ` + ${filteredAssets} hidden`
-						: filteredAssets
-			  } ${plural(filteredAssets, "asset", "assets")}`
+			? `${filteredAssets} ${plural(filteredAssets, "asset", "assets")}`
 			: undefined,
 	"compilation.logging": (logging, context, printer) =>
 		Array.isArray(logging)
@@ -141,9 +179,53 @@ const SIMPLE_PRINTERS = {
 					Object.entries(logging).map(([name, value]) => ({ ...value, name })),
 					context
 			  ),
-	"compilation.children[].compilation.name": name =>
-		name ? `Child ${name}:` : "Child",
+	"compilation.warningsInChildren!": (_, { yellow, compilation }) => {
+		if (
+			!compilation.children &&
+			compilation.warningsCount > 0 &&
+			compilation.warnings
+		) {
+			const childWarnings =
+				compilation.warningsCount - compilation.warnings.length;
+			if (childWarnings > 0) {
+				return yellow(
+					`${childWarnings} ${plural(
+						childWarnings,
+						"WARNING",
+						"WARNINGS"
+					)} in child compilations${
+						compilation.children
+							? ""
+							: " (Use 'stats.children: true' resp. '--stats-children' for more details)"
+					}`
+				);
+			}
+		}
+	},
+	"compilation.errorsInChildren!": (_, { red, compilation }) => {
+		if (
+			!compilation.children &&
+			compilation.errorsCount > 0 &&
+			compilation.errors
+		) {
+			const childErrors = compilation.errorsCount - compilation.errors.length;
+			if (childErrors > 0) {
+				return red(
+					`${childErrors} ${plural(
+						childErrors,
+						"ERROR",
+						"ERRORS"
+					)} in child compilations${
+						compilation.children
+							? ""
+							: " (Use 'stats.children: true' resp. '--stats-children' for more details)"
+					}`
+				);
+			}
+		}
+	},
 
+	"asset.type": type => type,
 	"asset.name": (name, { formatFilename, asset: { isOverSizeLimit } }) =>
 		formatFilename(name, isOverSizeLimit),
 	"asset.size": (
@@ -154,27 +236,58 @@ const SIMPLE_PRINTERS = {
 		emitted ? green(formatFlag("emitted")) : undefined,
 	"asset.comparedForEmit": (comparedForEmit, { yellow, formatFlag }) =>
 		comparedForEmit ? yellow(formatFlag("compared for emit")) : undefined,
+	"asset.cached": (cached, { green, formatFlag }) =>
+		cached ? green(formatFlag("cached")) : undefined,
 	"asset.isOverSizeLimit": (isOverSizeLimit, { yellow, formatFlag }) =>
 		isOverSizeLimit ? yellow(formatFlag("big")) : undefined,
 
 	"asset.info.immutable": (immutable, { green, formatFlag }) =>
 		immutable ? green(formatFlag("immutable")) : undefined,
+	"asset.info.javascriptModule": (javascriptModule, { formatFlag }) =>
+		javascriptModule ? formatFlag("javascript module") : undefined,
+	"asset.info.sourceFilename": (sourceFilename, { formatFlag }) =>
+		sourceFilename
+			? formatFlag(
+					sourceFilename === true
+						? "from source file"
+						: `from: ${sourceFilename}`
+			  )
+			: undefined,
 	"asset.info.development": (development, { green, formatFlag }) =>
 		development ? green(formatFlag("dev")) : undefined,
 	"asset.info.hotModuleReplacement": (
 		hotModuleReplacement,
 		{ green, formatFlag }
 	) => (hotModuleReplacement ? green(formatFlag("hmr")) : undefined),
+	"asset.separator!": () => "\n",
+	"asset.filteredRelated": (filteredRelated, { asset: { related } }) =>
+		filteredRelated > 0
+			? `${filteredRelated} related ${plural(
+					filteredRelated,
+					"asset",
+					"assets"
+			  )}`
+			: undefined,
+	"asset.filteredChildren": filteredChildren =>
+		filteredChildren > 0
+			? `${filteredChildren} ${plural(filteredChildren, "asset", "assets")}`
+			: undefined,
 
 	assetChunk: (id, { formatChunkId }) => formatChunkId(id),
 
 	assetChunkName: name => name,
 	assetChunkIdHint: name => name,
 
+	"module.type": type => (type !== "module" ? type : undefined),
 	"module.id": (id, { formatModuleId }) =>
 		isValidId(id) ? formatModuleId(id) : undefined,
-	"module.name": (name, { bold }) => bold(name),
-	"module.identifier": identifier => identifier,
+	"module.name": (name, { bold }) => {
+		const [, prefix, resource] = /^(.*!)?([^!]*)$/.exec(name);
+		return (prefix || "") + bold(resource);
+	},
+	"module.identifier": identifier => undefined,
+	"module.layer": (layer, { formatLayer }) =>
+		layer ? formatLayer(layer) : undefined,
 	"module.sizes": printSizes,
 	"module.chunks[]": (id, { formatChunkId }) => formatChunkId(id),
 	"module.depth": (depth, { formatFlag }) =>
@@ -187,8 +300,16 @@ const SIMPLE_PRINTERS = {
 		runtime ? yellow(formatFlag("runtime")) : undefined,
 	"module.optional": (optional, { formatFlag, yellow }) =>
 		optional ? yellow(formatFlag("optional")) : undefined,
-	"module.built": (built, { formatFlag, green }) =>
-		built ? green(formatFlag("built")) : undefined,
+	"module.dependent": (dependent, { formatFlag, cyan }) =>
+		dependent ? cyan(formatFlag("dependent")) : undefined,
+	"module.built": (built, { formatFlag, yellow }) =>
+		built ? yellow(formatFlag("built")) : undefined,
+	"module.codeGenerated": (codeGenerated, { formatFlag, yellow }) =>
+		codeGenerated ? yellow(formatFlag("code generated")) : undefined,
+	"module.buildTimeExecuted": (buildTimeExecuted, { formatFlag, green }) =>
+		buildTimeExecuted ? green(formatFlag("build time executed")) : undefined,
+	"module.cached": (cached, { formatFlag, green }) =>
+		cached ? green(formatFlag("cached")) : undefined,
 	"module.assets": (assets, { formatFlag, magenta }) =>
 		assets && assets.length
 			? magenta(
@@ -197,16 +318,18 @@ const SIMPLE_PRINTERS = {
 					)
 			  )
 			: undefined,
-	"module.failed": (failed, { formatFlag, red }) =>
-		failed ? red(formatFlag("failed")) : undefined,
 	"module.warnings": (warnings, { formatFlag, yellow }) =>
-		warnings
+		warnings === true
+			? yellow(formatFlag("warnings"))
+			: warnings
 			? yellow(
 					formatFlag(`${warnings} ${plural(warnings, "warning", "warnings")}`)
 			  )
 			: undefined,
 	"module.errors": (errors, { formatFlag, red }) =>
-		errors
+		errors === true
+			? red(formatFlag("errors"))
+			: errors
 			? red(formatFlag(`${errors} ${plural(errors, "error", "errors")}`))
 			: undefined,
 	"module.providedExports": (providedExports, { formatFlag, cyan }) => {
@@ -227,7 +350,7 @@ const SIMPLE_PRINTERS = {
 					: null;
 				if (
 					providedExportsCount !== null &&
-					providedExportsCount === module.usedExports.length
+					providedExportsCount === usedExports.length
 				) {
 					return cyan(formatFlag("all exports used"));
 				} else {
@@ -243,22 +366,21 @@ const SIMPLE_PRINTERS = {
 	"module.issuerPath": (issuerPath, { module }) =>
 		module.profile ? undefined : "",
 	"module.profile": profile => undefined,
-	"module.modules": (modules, context) => {
-		let maxModuleId = 0;
-		for (const module of modules) {
-			if (typeof module.id === "number") {
-				if (maxModuleId < module.id) maxModuleId = module.id;
-			}
-		}
-		context.maxModuleId = maxModuleId;
-	},
-	"module.filteredModules": (filteredModules, { compilation: { modules } }) =>
+	"module.filteredModules": filteredModules =>
 		filteredModules > 0
-			? `   ${
-					modules && modules.length > 0
-						? ` + ${filteredModules} hidden`
-						: filteredModules
-			  } nested ${plural(filteredModules, "module", "modules")}`
+			? `${filteredModules} nested ${plural(
+					filteredModules,
+					"module",
+					"modules"
+			  )}`
+			: undefined,
+	"module.filteredReasons": filteredReasons =>
+		filteredReasons > 0
+			? `${filteredReasons} ${plural(filteredReasons, "reason", "reasons")}`
+			: undefined,
+	"module.filteredChildren": filteredChildren =>
+		filteredChildren > 0
+			? `${filteredChildren} ${plural(filteredChildren, "module", "modules")}`
 			: undefined,
 	"module.separator!": () => "\n",
 
@@ -275,6 +397,10 @@ const SIMPLE_PRINTERS = {
 	"moduleReason.active": (active, { formatFlag }) =>
 		active ? undefined : formatFlag("inactive"),
 	"moduleReason.resolvedModule": (module, { magenta }) => magenta(module),
+	"moduleReason.filteredChildren": filteredChildren =>
+		filteredChildren > 0
+			? `${filteredChildren} ${plural(filteredChildren, "reason", "reasons")}`
+			: undefined,
 
 	"module.profile.total": (value, { formatTime }) => formatTime(value),
 	"module.profile.resolving": (value, { formatTime }) =>
@@ -293,31 +419,47 @@ const SIMPLE_PRINTERS = {
 		value ? `additional integration: ${formatTime(value)}` : undefined,
 
 	"chunkGroup.kind!": (_, { chunkGroupKind }) => chunkGroupKind,
+	"chunkGroup.separator!": () => "\n",
 	"chunkGroup.name": (name, { bold }) => bold(name),
 	"chunkGroup.isOverSizeLimit": (isOverSizeLimit, { formatFlag, yellow }) =>
 		isOverSizeLimit ? yellow(formatFlag("big")) : undefined,
-	"chunkGroup.separator!": () => "=",
-	"chunkGroup.assets[]": (asset, { green }) => green(asset),
-	"chunkGroup.auxiliaryAssets[]": (asset, { green }) => green(asset),
-	"chunkGroup.childAssets": (childAssets, context, printer) =>
-		Array.isArray(childAssets)
+	"chunkGroup.assetsSize": (size, { formatSize }) =>
+		size ? formatSize(size) : undefined,
+	"chunkGroup.auxiliaryAssetsSize": (size, { formatSize }) =>
+		size ? `(${formatSize(size)})` : undefined,
+	"chunkGroup.filteredAssets": n =>
+		n > 0 ? `${n} ${plural(n, "asset", "assets")}` : undefined,
+	"chunkGroup.filteredAuxiliaryAssets": n =>
+		n > 0 ? `${n} auxiliary ${plural(n, "asset", "assets")}` : undefined,
+	"chunkGroup.is!": () => "=",
+	"chunkGroupAsset.name": (asset, { green }) => green(asset),
+	"chunkGroupAsset.size": (size, { formatSize, chunkGroup }) =>
+		chunkGroup.assets.length > 1 ||
+		(chunkGroup.auxiliaryAssets && chunkGroup.auxiliaryAssets.length > 0)
+			? formatSize(size)
+			: undefined,
+	"chunkGroup.children": (children, context, printer) =>
+		Array.isArray(children)
 			? undefined
 			: printer.print(
 					context.type,
-					Object.keys(childAssets).map(key => ({
+					Object.keys(children).map(key => ({
 						type: key,
-						children: childAssets[key]
+						children: children[key]
 					})),
 					context
 			  ),
-	"chunkGroup.childAssets[].type": type => `${type}:`,
-	"chunkGroup.childAssets[].children[]": (file, { formatFilename }) =>
+	"chunkGroupChildGroup.type": type => `${type}:`,
+	"chunkGroupChild.assets[]": (file, { formatFilename }) =>
 		formatFilename(file),
+	"chunkGroupChild.chunks[]": (id, { formatChunkId }) => formatChunkId(id),
+	"chunkGroupChild.name": name => (name ? `(name: ${name})` : undefined),
 
 	"chunk.id": (id, { formatChunkId }) => formatChunkId(id),
 	"chunk.files[]": (file, { formatFilename }) => formatFilename(file),
 	"chunk.names[]": name => name,
 	"chunk.idHints[]": name => name,
+	"chunk.runtime[]": name => name,
 	"chunk.sizes": (sizes, context) => printSizes(sizes, context),
 	"chunk.parents[]": (parents, context) =>
 		context.formatChunkId(parents, "parent"),
@@ -348,53 +490,13 @@ const SIMPLE_PRINTERS = {
 	"chunk.recorded": (recorded, { formatFlag, green }) =>
 		recorded ? green(formatFlag("recorded")) : undefined,
 	"chunk.reason": (reason, { yellow }) => (reason ? yellow(reason) : undefined),
-	"chunk.rootModules": (modules, context) => {
-		let maxModuleId = 0;
-		for (const module of modules) {
-			if (typeof module.id === "number") {
-				if (maxModuleId < module.id) maxModuleId = module.id;
-			}
-		}
-		context.maxModuleId = maxModuleId;
-	},
-	"chunk.filteredRootModules": (
-		filteredRootModules,
-		{ chunk: { rootModules } }
-	) =>
-		filteredRootModules > 0
-			? `   ${
-					rootModules && rootModules.length > 0
-						? ` + ${filteredRootModules} hidden`
-						: filteredRootModules
-			  } root ${plural(filteredRootModules, "module", "modules")}`
-			: undefined,
-	"chunk.nonRootModules": (
-		nonRootModules,
-		{ chunk: { filteredRootModules, rootModules } }
-	) =>
-		nonRootModules > 0
-			? `   ${
-					(rootModules && rootModules.length > 0) || filteredRootModules > 0
-						? ` + ${nonRootModules} hidden`
-						: nonRootModules
-			  } dependent ${plural(nonRootModules, "module", "modules")}`
-			: undefined,
-	"chunk.modules": (modules, context) => {
-		let maxModuleId = 0;
-		for (const module of modules) {
-			if (typeof module.id === "number") {
-				if (maxModuleId < module.id) maxModuleId = module.id;
-			}
-		}
-		context.maxModuleId = maxModuleId;
-	},
-	"chunk.filteredModules": (filteredModules, { chunk: { modules } }) =>
+	"chunk.filteredModules": filteredModules =>
 		filteredModules > 0
-			? `   ${
-					modules && modules.length > 0
-						? ` + ${filteredModules} hidden`
-						: filteredModules
-			  } chunk ${plural(filteredModules, "module", "modules")}`
+			? `${filteredModules} chunk ${plural(
+					filteredModules,
+					"module",
+					"modules"
+			  )}`
 			: undefined,
 	"chunk.separator!": () => "\n",
 
@@ -419,8 +521,9 @@ const SIMPLE_PRINTERS = {
 			: `${bold(moduleName)}`;
 	},
 	"error.loc": (loc, { green }) => green(loc),
-	"error.message": (message, { bold }) => bold(message),
-	"error.details": details => details,
+	"error.message": (message, { bold, formatError }) =>
+		message.includes("\u001b[") ? message : bold(formatError(message)),
+	"error.details": (details, { formatError }) => formatError(details),
 	"error.stack": stack => stack,
 	"error.moduleTrace": moduleTrace => undefined,
 	"error.separator!": () => "\n",
@@ -478,17 +581,26 @@ const ITEM_NAMES = {
 	"compilation.warnings[]": "error",
 	"compilation.logging[]": "loggingGroup",
 	"compilation.children[]": "compilation",
+	"asset.related[]": "asset",
+	"asset.children[]": "asset",
 	"asset.chunks[]": "assetChunk",
 	"asset.auxiliaryChunks[]": "assetChunk",
 	"asset.chunkNames[]": "assetChunkName",
 	"asset.chunkIdHints[]": "assetChunkIdHint",
 	"asset.auxiliaryChunkNames[]": "assetChunkName",
 	"asset.auxiliaryChunkIdHints[]": "assetChunkIdHint",
+	"chunkGroup.assets[]": "chunkGroupAsset",
+	"chunkGroup.auxiliaryAssets[]": "chunkGroupAsset",
+	"chunkGroupChild.assets[]": "chunkGroupAsset",
+	"chunkGroupChild.auxiliaryAssets[]": "chunkGroupAsset",
+	"chunkGroup.children[]": "chunkGroupChildGroup",
+	"chunkGroupChildGroup.children[]": "chunkGroupChild",
 	"module.modules[]": "module",
+	"module.children[]": "module",
 	"module.reasons[]": "moduleReason",
+	"moduleReason.children[]": "moduleReason",
 	"module.issuerPath[]": "moduleIssuer",
 	"chunk.origins[]": "chunkOrigin",
-	"chunk.rootModules[]": "module",
 	"chunk.modules[]": "module",
 	"loggingGroup.entries[]": logEntry =>
 		`loggingEntry(${logEntry.type}).loggingEntry`,
@@ -536,40 +648,67 @@ const PREFERRED_ORDERS = {
 		"chunks",
 		"modules",
 		"filteredModules",
+		"children",
 		"logging",
 		"warnings",
+		"warningsInChildren!",
+		"filteredWarningDetailsCount",
 		"errors",
-		"children",
+		"errorsInChildren!",
+		"filteredErrorDetailsCount",
+		"summary!",
 		"needAdditionalPass"
 	],
 	asset: [
+		"type",
 		"name",
 		"size",
 		"chunks",
 		"auxiliaryChunks",
 		"emitted",
 		"comparedForEmit",
+		"cached",
 		"info",
 		"isOverSizeLimit",
 		"chunkNames",
 		"auxiliaryChunkNames",
 		"chunkIdHints",
-		"auxiliaryChunkIdHints"
+		"auxiliaryChunkIdHints",
+		"related",
+		"filteredRelated",
+		"children",
+		"filteredChildren"
+	],
+	"asset.info": [
+		"immutable",
+		"sourceFilename",
+		"javascriptModule",
+		"development",
+		"hotModuleReplacement"
 	],
-	"asset.info": ["immutable", "development", "hotModuleReplacement"],
 	chunkGroup: [
 		"kind!",
 		"name",
 		"isOverSizeLimit",
-		"separator!",
+		"assetsSize",
+		"auxiliaryAssetsSize",
+		"is!",
 		"assets",
+		"filteredAssets",
 		"auxiliaryAssets",
-		"childAssets"
+		"filteredAuxiliaryAssets",
+		"separator!",
+		"children"
 	],
+	chunkGroupAsset: ["name", "size"],
+	chunkGroupChildGroup: ["type", "children"],
+	chunkGroupChild: ["assets", "chunks", "name"],
 	module: [
-		"id",
+		"type",
 		"name",
 		"identifier",
+		"id",
+		"layer",
 		"sizes",
 		"chunks",
 		"depth",
@@ -577,24 +716,25 @@ const PREFERRED_ORDERS = {
 		"orphan",
 		"runtime",
 		"optional",
+		"dependent",
 		"built",
+		"codeGenerated",
+		"cached",
 		"assets",
 		"failed",
 		"warnings",
 		"errors",
-		"separator!",
+		"children",
+		"filteredChildren",
 		"providedExports",
-		"separator!",
 		"usedExports",
-		"separator!",
 		"optimizationBailout",
-		"separator!",
 		"reasons",
-		"separator!",
+		"filteredReasons",
 		"issuerPath",
 		"profile",
-		"separator!",
-		"modules"
+		"modules",
+		"filteredModules"
 	],
 	moduleReason: [
 		"active",
@@ -604,7 +744,9 @@ const PREFERRED_ORDERS = {
 		"module",
 		"resolvedModule",
 		"loc",
-		"explanation"
+		"explanation",
+		"children",
+		"filteredChildren"
 	],
 	"module.profile": [
 		"total",
@@ -619,6 +761,7 @@ const PREFERRED_ORDERS = {
 	],
 	chunk: [
 		"id",
+		"runtime",
 		"files",
 		"names",
 		"idHints",
@@ -635,12 +778,6 @@ const PREFERRED_ORDERS = {
 		"separator!",
 		"origins",
 		"separator!",
-		"rootModules",
-		"separator!",
-		"filteredRootModules",
-		"separator!",
-		"nonRootModules",
-		"separator!",
 		"modules",
 		"separator!",
 		"filteredModules"
@@ -657,8 +794,7 @@ const PREFERRED_ORDERS = {
 		"separator!",
 		"filteredEntries"
 	],
-	loggingEntry: ["message", "trace", "children"],
-	"chunkGroup.childAssets[]": ["type", "children"]
+	loggingEntry: ["message", "trace", "children"]
 };
 
 const itemsJoinOneLine = items => items.filter(Boolean).join(" ");
@@ -680,19 +816,22 @@ const SIMPLE_ITEMS_JOINER = {
 	"chunk.children": itemsJoinOneLine,
 	"chunk.names": itemsJoinCommaBrackets,
 	"chunk.idHints": itemsJoinCommaBracketsWithName("id hint"),
+	"chunk.runtime": itemsJoinCommaBracketsWithName("runtime"),
 	"chunk.files": itemsJoinComma,
 	"chunk.childrenByOrder": itemsJoinOneLine,
 	"chunk.childrenByOrder[].children": itemsJoinOneLine,
 	"chunkGroup.assets": itemsJoinOneLine,
 	"chunkGroup.auxiliaryAssets": itemsJoinOneLineBrackets,
-	"chunkGroup.childAssets": itemsJoinOneLine,
-	"chunkGroup.childAssets[].children": itemsJoinOneLine,
+	"chunkGroupChildGroup.children": itemsJoinComma,
+	"chunkGroupChild.assets": itemsJoinOneLine,
+	"chunkGroupChild.auxiliaryAssets": itemsJoinOneLineBrackets,
 	"asset.chunks": itemsJoinComma,
 	"asset.auxiliaryChunks": itemsJoinCommaBrackets,
-	"asset.chunkNames": itemsJoinComma,
-	"asset.auxiliaryChunkNames": itemsJoinCommaBrackets,
-	"asset.chunkIdHints": itemsJoinComma,
-	"asset.auxiliaryChunkIdHints": itemsJoinCommaBrackets,
+	"asset.chunkNames": itemsJoinCommaBracketsWithName("name"),
+	"asset.auxiliaryChunkNames": itemsJoinCommaBracketsWithName("auxiliary name"),
+	"asset.chunkIdHints": itemsJoinCommaBracketsWithName("id hint"),
+	"asset.auxiliaryChunkIdHints":
+		itemsJoinCommaBracketsWithName("auxiliary id hint"),
 	"module.chunks": itemsJoinOneLine,
 	"module.issuerPath": items =>
 		items
@@ -702,11 +841,10 @@ const SIMPLE_ITEMS_JOINER = {
 	"compilation.errors": itemsJoinMoreSpacing,
 	"compilation.warnings": itemsJoinMoreSpacing,
 	"compilation.logging": itemsJoinMoreSpacing,
+	"compilation.children": items => indent(itemsJoinMoreSpacing(items), "  "),
 	"moduleTraceItem.dependencies": itemsJoinOneLine,
 	"loggingEntry.children": items =>
-		indent(items.filter(Boolean).join("\n"), "  ", false),
-	"compilation.children": items =>
-		items.map(item => indent(item, "    ", true)).join("\n")
+		indent(items.filter(Boolean).join("\n"), "  ", false)
 };
 
 const joinOneLine = items =>
@@ -766,14 +904,16 @@ const indent = (str, prefix, noPrefixInFirstLine) => {
 
 const joinExplicitNewLine = (items, indenter) => {
 	let firstInLine = true;
+	let first = true;
 	return items
 		.map(item => {
-			if (!item.content) return;
-			let content = indent(item.content, indenter, !firstInLine);
+			if (!item || !item.content) return;
+			let content = indent(item.content, first ? "" : indenter, !firstInLine);
 			if (firstInLine) {
 				content = content.replace(/^\n+/, "");
 			}
 			if (!content) return;
+			first = false;
 			const noJoiner = firstInLine || content.startsWith("\n");
 			firstInLine = content.endsWith("\n");
 			return noJoiner ? content : " " + content;
@@ -783,13 +923,15 @@ const joinExplicitNewLine = (items, indenter) => {
 		.trim();
 };
 
-const joinError = error => (items, { red, yellow }) =>
-	`${error ? red("ERROR") : yellow("WARNING")} in ${joinExplicitNewLine(
-		items,
-		""
-	)}`;
+const joinError =
+	error =>
+	(items, { red, yellow }) =>
+		`${error ? red("ERROR") : yellow("WARNING")} in ${joinExplicitNewLine(
+			items,
+			""
+		)}`;
 
-/** @type {Record<string, (items: ({ element: string, content: string })[], context: UsualContext) => string>} */
+/** @type {Record<string, (items: ({ element: string, content: string })[], context: StatsPrinterContext) => string>} */
 const SIMPLE_ELEMENT_JOINERS = {
 	compilation: items => {
 		const result = [];
@@ -798,7 +940,9 @@ const SIMPLE_ELEMENT_JOINERS = {
 			if (!item.content) continue;
 			const needMoreSpace =
 				item.element === "warnings" ||
+				item.element === "filteredWarningDetailsCount" ||
 				item.element === "errors" ||
+				item.element === "filteredErrorDetailsCount" ||
 				item.element === "logging";
 			if (result.length !== 0) {
 				result.push(needMoreSpace || lastNeedMore ? "\n\n" : "\n");
@@ -809,40 +953,57 @@ const SIMPLE_ELEMENT_JOINERS = {
 		if (lastNeedMore) result.push("\n");
 		return result.join("");
 	},
-	module: (items, { module, maxModuleId }) => {
+	asset: items =>
+		joinExplicitNewLine(
+			items.map(item => {
+				if (
+					(item.element === "related" || item.element === "children") &&
+					item.content
+				) {
+					return {
+						...item,
+						content: `\n${item.content}\n`
+					};
+				}
+				return item;
+			}),
+			"  "
+		),
+	"asset.info": joinOneLine,
+	module: (items, { module }) => {
 		let hasName = false;
-		let indenter = "    ";
-		if (maxModuleId >= 10) indenter += " ";
-		if (maxModuleId >= 100) indenter += " ";
-		if (maxModuleId >= 1000) indenter += " ";
-		let prefix = "";
-		if (typeof module.id === "number") {
-			if (module.id < 1000 && maxModuleId >= 1000) prefix += " ";
-			if (module.id < 100 && maxModuleId >= 100) prefix += " ";
-			if (module.id < 10 && maxModuleId >= 10) prefix += " ";
-		} else if (typeof module.id === "string" && module.id !== "") {
-			if (maxModuleId >= 1000) prefix += " ";
-			if (maxModuleId >= 100) prefix += " ";
-			if (maxModuleId >= 10) prefix += " ";
-		}
-		return (
-			prefix +
-			joinExplicitNewLine(
-				items.filter(item => {
-					switch (item.element) {
-						case "id":
-							if (module.id === module.name && item.content) hasName = true;
-							break;
-						case "name":
-						case "identifier":
+		return joinExplicitNewLine(
+			items.map(item => {
+				switch (item.element) {
+					case "id":
+						if (module.id === module.name) {
 							if (hasName) return false;
 							if (item.content) hasName = true;
-							break;
-					}
-					return true;
-				}),
-				indenter
-			)
+						}
+						break;
+					case "name":
+						if (hasName) return false;
+						if (item.content) hasName = true;
+						break;
+					case "providedExports":
+					case "usedExports":
+					case "optimizationBailout":
+					case "reasons":
+					case "issuerPath":
+					case "profile":
+					case "children":
+					case "modules":
+						if (item.content) {
+							return {
+								...item,
+								content: `\n${item.content}\n`
+							};
+						}
+						break;
+				}
+				return item;
+			}),
+			"  "
 		);
 	},
 	chunk: items => {
@@ -861,17 +1022,41 @@ const SIMPLE_ELEMENT_JOINERS = {
 					}
 					return true;
 				}),
-				" "
+				"  "
 			)
 		);
 	},
 	"chunk.childrenByOrder[]": items => `(${joinOneLine(items)})`,
-	chunkGroup: joinOneLine,
-	"chunkGroup.childAssets[]": items => `(${joinOneLine(items)})`,
+	chunkGroup: items => joinExplicitNewLine(items, "  "),
+	chunkGroupAsset: joinOneLine,
+	chunkGroupChildGroup: joinOneLine,
+	chunkGroupChild: joinOneLine,
+	// moduleReason: (items, { moduleReason }) => {
+	// 	let hasName = false;
+	// 	return joinOneLine(
+	// 		items.filter(item => {
+	// 			switch (item.element) {
+	// 				case "moduleId":
+	// 					if (moduleReason.moduleId === moduleReason.module && item.content)
+	// 						hasName = true;
+	// 					break;
+	// 				case "module":
+	// 					if (hasName) return false;
+	// 					break;
+	// 				case "resolvedModule":
+	// 					return (
+	// 						moduleReason.module !== moduleReason.resolvedModule &&
+	// 						item.content
+	// 					);
+	// 			}
+	// 			return true;
+	// 		})
+	// 	);
+	// },
 	moduleReason: (items, { moduleReason }) => {
 		let hasName = false;
-		return joinOneLine(
-			items.filter(item => {
+		return joinExplicitNewLine(
+			items.map(item => {
 				switch (item.element) {
 					case "moduleId":
 						if (moduleReason.moduleId === moduleReason.module && item.content)
@@ -881,18 +1066,26 @@ const SIMPLE_ELEMENT_JOINERS = {
 						if (hasName) return false;
 						break;
 					case "resolvedModule":
-						return (
-							moduleReason.module !== moduleReason.resolvedModule &&
-							item.content
-						);
+						if (moduleReason.module === moduleReason.resolvedModule)
+							return false;
+						break;
+					case "children":
+						if (item.content) {
+							return {
+								...item,
+								content: `\n${item.content}\n`
+							};
+						}
+						break;
 				}
-				return true;
-			})
+				return item;
+			}),
+			"  "
 		);
 	},
 	"module.profile": joinInBrackets,
 	moduleIssuer: joinOneLine,
-	chunkOrigin: items => "   > " + joinOneLine(items),
+	chunkOrigin: items => "> " + joinOneLine(items),
 	"errors[].error": joinError(true),
 	"warnings[].error": joinError(false),
 	loggingGroup: items => joinExplicitNewLine(items, "").trimRight(),
@@ -926,7 +1119,15 @@ const AVAILABLE_FORMATS = {
 	formatFilename: (filename, { green, yellow }, oversize) =>
 		(oversize ? yellow : green)(filename),
 	formatFlag: flag => `[${flag}]`,
+	formatLayer: layer => `(in ${layer})`,
 	formatSize: require("../SizeFormatHelpers").formatSize,
+	formatDateTime: (dateTime, { bold }) => {
+		const d = new Date(dateTime);
+		const x = twoDigit;
+		const date = `${d.getFullYear()}-${x(d.getMonth() + 1)}-${x(d.getDate())}`;
+		const time = `${x(d.getHours())}:${x(d.getMinutes())}:${x(d.getSeconds())}`;
+		return `${date} ${bold(time)}`;
+	},
 	formatTime: (
 		time,
 		{ timeReference, bold, green, yellow, red },
@@ -948,6 +1149,41 @@ const AVAILABLE_FORMATS = {
 		} else {
 			return `${boldQuantity ? bold(time) : time}${unit}`;
 		}
+	},
+	formatError: (message, { green, yellow, red }) => {
+		if (message.includes("\u001b[")) return message;
+		const highlights = [
+			{ regExp: /(Did you mean .+)/g, format: green },
+			{
+				regExp: /(Set 'mode' option to 'development' or 'production')/g,
+				format: green
+			},
+			{ regExp: /(\(module has no exports\))/g, format: red },
+			{ regExp: /\(possible exports: (.+)\)/g, format: green },
+			{ regExp: /(?:^|\n)(.* doesn't exist)/g, format: red },
+			{ regExp: /('\w+' option has not been set)/g, format: red },
+			{
+				regExp: /(Emitted value instead of an instance of Error)/g,
+				format: yellow
+			},
+			{ regExp: /(Used? .+ instead)/gi, format: yellow },
+			{ regExp: /\b(deprecated|must|required)\b/g, format: yellow },
+			{
+				regExp: /\b(BREAKING CHANGE)\b/gi,
+				format: red
+			},
+			{
+				regExp:
+					/\b(error|failed|unexpected|invalid|not found|not supported|not available|not possible|not implemented|doesn't support|conflict|conflicting|not existing|duplicate)\b/gi,
+				format: red
+			}
+		];
+		for (const { regExp, format } of highlights) {
+			message = message.replace(regExp, (match, content) => {
+				return match.replace(content, format(content));
+			});
+		}
+		return message;
 	}
 };
 
@@ -976,56 +1212,6 @@ const createOrder = (array, preferredOrder) => {
 	return array;
 };
 
-const filterColors = value => value.replace(/\u001b\[\d+m/g, "");
-
-const table = (array, align, splitter) => {
-	const rows = array.length;
-	const cols = array[0].length;
-	const colSizes = new Array(cols);
-	for (let col = 0; col < cols; col++) {
-		colSizes[col] = 0;
-	}
-	// measure content
-	for (let row = 1; row < rows; row++) {
-		for (let col = 0; col < cols; col++) {
-			const value = filterColors(`${array[row][col]}`);
-			if (value.length > colSizes[col]) {
-				colSizes[col] = value.length;
-			}
-		}
-	}
-	// measure headers
-	for (let col = 0; col < cols; col++) {
-		const value = filterColors(`${array[0][col]}`);
-		if (colSizes[col] > 0 && value.length > colSizes[col]) {
-			colSizes[col] = value.length;
-		}
-	}
-	const lines = [];
-	for (let row = 0; row < rows; row++) {
-		let str = "";
-		for (let col = 0; col < cols; col++) {
-			if (colSizes[col] === 0) continue;
-			const value = `${array[row][col]}`;
-			let l = filterColors(value).length;
-			if (align[col] === "l") {
-				str += value;
-			}
-			for (; l < colSizes[col] && col !== cols - 1; l++) {
-				str += " ";
-			}
-			if (align[col] === "r") {
-				str += value;
-			}
-			if (col + 1 < cols && colSizes[col] !== 0) {
-				str += splitter || "  ";
-			}
-		}
-		lines.push(str.trimRight());
-	}
-	return lines.join("\n");
-};
-
 class DefaultStatsPrinterPlugin {
 	/**
 	 * Apply the plugin
@@ -1054,7 +1240,15 @@ class DefaultStatsPrinterPlugin {
 									}
 								}
 								if (start) {
-									context[color] = str => `${start}${str}\u001b[39m\u001b[22m`;
+									context[color] = str =>
+										`${start}${
+											typeof str === "string"
+												? str.replace(
+														/((\u001b\[39m|\u001b\[22m|\u001b\[0m)+)/g,
+														`$1${start}`
+												  )
+												: str
+										}\u001b[39m\u001b[22m`;
 								} else {
 									context[color] = str => str;
 								}
@@ -1113,57 +1307,6 @@ class DefaultStatsPrinterPlugin {
 							.for(key)
 							.tap("DefaultStatsPrinterPlugin", modifier);
 					}
-
-					// Print assets as table
-					stats.hooks.printElements
-						.for("compilation.assets[].asset")
-						.tap("DefaultStatsPrinterPlugin", (elements, { formatFlag }) => {
-							const elementsMap = elements.reduce(
-								(obj, e) => ((obj[e.element] = e.content), obj),
-								Object.create(null)
-							);
-							const chunkNames = [
-								elementsMap.chunkNames,
-								elementsMap.auxiliaryChunkNames
-							]
-								.filter(Boolean)
-								.join(" ");
-							const idHints = [
-								elementsMap.chunkIdHints,
-								elementsMap.auxiliaryChunkIdHints
-							]
-								.filter(Boolean)
-								.join(" ");
-							return [
-								elementsMap.name || "",
-								elementsMap.size || "",
-								[elementsMap.chunks, elementsMap.auxiliaryChunks]
-									.filter(Boolean)
-									.join(" "),
-								[
-									elementsMap.emitted,
-									elementsMap.comparedForEmit,
-									elementsMap.info
-								]
-									.filter(Boolean)
-									.join(" "),
-								elementsMap.isOverSizeLimit || "",
-								[
-									chunkNames && formatFlag(`name: ${chunkNames}`),
-									idHints && formatFlag(`id hint: ${idHints}`)
-								]
-									.filter(Boolean)
-									.join(" ")
-							];
-						});
-					stats.hooks.printItems
-						.for("compilation.assets")
-						.tap("DefaultStatsPrinterPlugin", (items, { bold }) => {
-							if (items.length === 0) return undefined;
-							let header = ["Asset", "Size", "Chunks", "", "", ""];
-							header = header.map(h => (h ? bold(h) : h));
-							return table([header].concat(items), "rrrlll");
-						});
 				}
 			);
 		});
